@@ -40,4 +40,27 @@ def CLES_2paired(data1, data2):
             elif d1 == d2: 
                 total += 0.5
     thetaHat = (numpy.abs(total / (len(data1) * len(data2)) - 0.5) + 0.5) * 100
-    return thetaHat 
\ No newline at end of file
+    return thetaHat 
+
+def CLES_1samp(data, mu=0):
+    '''
+    Calculate common language effect size (1 sample)
+
+    INPUTS:
+    data: data vector 
+    mu: mean to compare, default=0
+
+    OUTPUT:
+    thetaHat: common language effect size (50 - 100)
+    '''
+    import numpy 
+    comp = numpy.repeat(mu, len(data)) # mean value to compare 
+    total = 0
+    for d1 in data:
+        for d2 in comp:
+            if d1 > d2: 
+                total += 1
+            elif d1 == d2: 
+                total += 0.5
+    thetaHat = (numpy.abs(total / (len(data) * len(comp)) - 0.5) + 0.5) * 100
+    return thetaHat
\ No newline at end of file
